@@ -17,18 +17,26 @@ class ConjurEndpoint(Enum):
     required parameters for the paths
     """
     AUTHENTICATE = "{url}/authn/{account}/{login}/authenticate"
+    AUTHENTICATE_LDAP = "{url}/authn-ldap/{service_id}/{account}/{login}/authenticate"
+    AUTHENTICATE_OIDC = "{url}/authn-oidc/{service_id}/{account}/authenticate"
     LOGIN = "{url}/authn/{account}/login"
+    LOGIN_LDAP = "{url}/authn-ldap/{service_id}/{account}/login"
     INFO = "{url}/info"
     POLICIES = "{url}/policies/{account}/policy/{identifier}"
     BATCH_SECRETS = "{url}/secrets"
     SECRETS = "{url}/secrets/{account}/{kind}/{identifier}"
+    PRIVILEGE = "{url}/resources/{account}/{kind}/{identifier}?check=true&role={role}&privilege={privilege}"
     RESOURCES = "{url}/resources/{account}"
+    RESOURCE = "{url}/resources/{account}/{kind}/{identifier}"
     ROTATE_API_KEY = "{url}/authn/{account}/api_key"
     CHANGE_PASSWORD = "{url}/authn/{account}/password"
     WHOAMI = "{url}/whoami"
     HOST_FACTORY_TOKENS = "{url}/host_factory_tokens"
     HOST_FACTORY_REVOKE_TOKEN = "{url}/host_factory_tokens/{token}"
     HOST_FACTORY_HOSTS = "{url}/host_factories/hosts"
+    ROLE = "{url}/roles/{account}/{kind}/{identifier}"
     ROLES_MEMBERS_OF = "{url}/roles/{account}/{kind}/{identifier}?members"
+    ROLES_MEMBERSHIPS = "{url}/roles/{account}/{kind}/{identifier}?{membership}"
     RESOURCES_PERMITTED_ROLES =\
         "{url}/resources/{account}/{kind}/{identifier}?permitted_roles=true&privilege={privilege}"
+    AUTHENTICATOR = "{url}/{authenticator_id}/{account}"
